"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.rating.cylindrical.iso6336._621 import (
        CylindricalGearToothFatigueFractureResults,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._622 import (
        CylindricalGearToothFatigueFractureResultsN1457,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._623 import (
        HelicalGearMicroGeometryOption,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._624 import (
        ISO63361996GearSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._625 import (
        ISO63361996MeshSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._626 import (
        ISO63362006GearSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._627 import (
        ISO63362006MeshSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._628 import (
        ISO63362019GearSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._629 import (
        ISO63362019MeshSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._630 import (
        ISO6336AbstractGearSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._631 import (
        ISO6336AbstractMeshSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._632 import (
        ISO6336AbstractMetalGearSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._633 import (
        ISO6336AbstractMetalMeshSingleFlankRating,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._634 import (
        ISO6336MeanStressInfluenceFactor,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._635 import (
        ISO6336MetalRateableMesh,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._636 import (
        ISO6336RateableMesh,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._637 import (
        ToothFlankFractureAnalysisContactPoint,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._638 import (
        ToothFlankFractureAnalysisContactPointCommon,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._639 import (
        ToothFlankFractureAnalysisContactPointMethodA,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._640 import (
        ToothFlankFractureAnalysisContactPointN1457,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._641 import (
        ToothFlankFractureAnalysisPoint,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._642 import (
        ToothFlankFractureAnalysisPointN1457,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._643 import (
        ToothFlankFractureAnalysisRowN1457,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336._644 import (
        ToothFlankFractureStressStepAtAnalysisPointN1457,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.rating.cylindrical.iso6336._621": [
            "CylindricalGearToothFatigueFractureResults"
        ],
        "_private.gears.rating.cylindrical.iso6336._622": [
            "CylindricalGearToothFatigueFractureResultsN1457"
        ],
        "_private.gears.rating.cylindrical.iso6336._623": [
            "HelicalGearMicroGeometryOption"
        ],
        "_private.gears.rating.cylindrical.iso6336._624": [
            "ISO63361996GearSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._625": [
            "ISO63361996MeshSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._626": [
            "ISO63362006GearSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._627": [
            "ISO63362006MeshSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._628": [
            "ISO63362019GearSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._629": [
            "ISO63362019MeshSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._630": [
            "ISO6336AbstractGearSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._631": [
            "ISO6336AbstractMeshSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._632": [
            "ISO6336AbstractMetalGearSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._633": [
            "ISO6336AbstractMetalMeshSingleFlankRating"
        ],
        "_private.gears.rating.cylindrical.iso6336._634": [
            "ISO6336MeanStressInfluenceFactor"
        ],
        "_private.gears.rating.cylindrical.iso6336._635": ["ISO6336MetalRateableMesh"],
        "_private.gears.rating.cylindrical.iso6336._636": ["ISO6336RateableMesh"],
        "_private.gears.rating.cylindrical.iso6336._637": [
            "ToothFlankFractureAnalysisContactPoint"
        ],
        "_private.gears.rating.cylindrical.iso6336._638": [
            "ToothFlankFractureAnalysisContactPointCommon"
        ],
        "_private.gears.rating.cylindrical.iso6336._639": [
            "ToothFlankFractureAnalysisContactPointMethodA"
        ],
        "_private.gears.rating.cylindrical.iso6336._640": [
            "ToothFlankFractureAnalysisContactPointN1457"
        ],
        "_private.gears.rating.cylindrical.iso6336._641": [
            "ToothFlankFractureAnalysisPoint"
        ],
        "_private.gears.rating.cylindrical.iso6336._642": [
            "ToothFlankFractureAnalysisPointN1457"
        ],
        "_private.gears.rating.cylindrical.iso6336._643": [
            "ToothFlankFractureAnalysisRowN1457"
        ],
        "_private.gears.rating.cylindrical.iso6336._644": [
            "ToothFlankFractureStressStepAtAnalysisPointN1457"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "CylindricalGearToothFatigueFractureResults",
    "CylindricalGearToothFatigueFractureResultsN1457",
    "HelicalGearMicroGeometryOption",
    "ISO63361996GearSingleFlankRating",
    "ISO63361996MeshSingleFlankRating",
    "ISO63362006GearSingleFlankRating",
    "ISO63362006MeshSingleFlankRating",
    "ISO63362019GearSingleFlankRating",
    "ISO63362019MeshSingleFlankRating",
    "ISO6336AbstractGearSingleFlankRating",
    "ISO6336AbstractMeshSingleFlankRating",
    "ISO6336AbstractMetalGearSingleFlankRating",
    "ISO6336AbstractMetalMeshSingleFlankRating",
    "ISO6336MeanStressInfluenceFactor",
    "ISO6336MetalRateableMesh",
    "ISO6336RateableMesh",
    "ToothFlankFractureAnalysisContactPoint",
    "ToothFlankFractureAnalysisContactPointCommon",
    "ToothFlankFractureAnalysisContactPointMethodA",
    "ToothFlankFractureAnalysisContactPointN1457",
    "ToothFlankFractureAnalysisPoint",
    "ToothFlankFractureAnalysisPointN1457",
    "ToothFlankFractureAnalysisRowN1457",
    "ToothFlankFractureStressStepAtAnalysisPointN1457",
)



"""AbstractAssemblyMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5806

_ABSTRACT_ASSEMBLY_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "AbstractAssemblyMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7947,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
        _5718,
        _5720,
        _5725,
        _5728,
        _5733,
        _5734,
        _5738,
        _5744,
        _5747,
        _5750,
        _5755,
        _5757,
        _5759,
        _5765,
        _5771,
        _5773,
        _5777,
        _5781,
        _5789,
        _5792,
        _5795,
        _5801,
        _5809,
        _5811,
        _5818,
        _5821,
        _5828,
        _5831,
        _5835,
        _5838,
        _5841,
        _5845,
        _5850,
        _5859,
        _5862,
    )
    from mastapy._private.system_model.part_model import _2704

    Self = TypeVar("Self", bound="AbstractAssemblyMultibodyDynamicsAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AbstractAssemblyMultibodyDynamicsAnalysis._Cast_AbstractAssemblyMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AbstractAssemblyMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AbstractAssemblyMultibodyDynamicsAnalysis:
    """Special nested class for casting AbstractAssemblyMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "AbstractAssemblyMultibodyDynamicsAnalysis"

    @property
    def part_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5806.PartMultibodyDynamicsAnalysis":
        return self.__parent__._cast(_5806.PartMultibodyDynamicsAnalysis)

    @property
    def part_time_series_load_analysis_case(
        self: "CastSelf",
    ) -> "_7947.PartTimeSeriesLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7947,
        )

        return self.__parent__._cast(_7947.PartTimeSeriesLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5718.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5718,
        )

        return self.__parent__._cast(
            _5718.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis
        )

    @property
    def assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5720.AssemblyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5720,
        )

        return self.__parent__._cast(_5720.AssemblyMultibodyDynamicsAnalysis)

    @property
    def belt_drive_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5725.BeltDriveMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5725,
        )

        return self.__parent__._cast(_5725.BeltDriveMultibodyDynamicsAnalysis)

    @property
    def bevel_differential_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5728.BevelDifferentialGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5728,
        )

        return self.__parent__._cast(
            _5728.BevelDifferentialGearSetMultibodyDynamicsAnalysis
        )

    @property
    def bevel_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5733.BevelGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5733,
        )

        return self.__parent__._cast(_5733.BevelGearSetMultibodyDynamicsAnalysis)

    @property
    def bolted_joint_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5734.BoltedJointMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5734,
        )

        return self.__parent__._cast(_5734.BoltedJointMultibodyDynamicsAnalysis)

    @property
    def clutch_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5738.ClutchMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5738,
        )

        return self.__parent__._cast(_5738.ClutchMultibodyDynamicsAnalysis)

    @property
    def concept_coupling_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5744.ConceptCouplingMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5744,
        )

        return self.__parent__._cast(_5744.ConceptCouplingMultibodyDynamicsAnalysis)

    @property
    def concept_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5747.ConceptGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5747,
        )

        return self.__parent__._cast(_5747.ConceptGearSetMultibodyDynamicsAnalysis)

    @property
    def conical_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5750.ConicalGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5750,
        )

        return self.__parent__._cast(_5750.ConicalGearSetMultibodyDynamicsAnalysis)

    @property
    def coupling_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5755.CouplingMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5755,
        )

        return self.__parent__._cast(_5755.CouplingMultibodyDynamicsAnalysis)

    @property
    def cvt_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5757.CVTMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5757,
        )

        return self.__parent__._cast(_5757.CVTMultibodyDynamicsAnalysis)

    @property
    def cycloidal_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5759.CycloidalAssemblyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5759,
        )

        return self.__parent__._cast(_5759.CycloidalAssemblyMultibodyDynamicsAnalysis)

    @property
    def cylindrical_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5765.CylindricalGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5765,
        )

        return self.__parent__._cast(_5765.CylindricalGearSetMultibodyDynamicsAnalysis)

    @property
    def face_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5771.FaceGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5771,
        )

        return self.__parent__._cast(_5771.FaceGearSetMultibodyDynamicsAnalysis)

    @property
    def flexible_pin_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5773.FlexiblePinAssemblyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5773,
        )

        return self.__parent__._cast(_5773.FlexiblePinAssemblyMultibodyDynamicsAnalysis)

    @property
    def gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5777.GearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5777,
        )

        return self.__parent__._cast(_5777.GearSetMultibodyDynamicsAnalysis)

    @property
    def hypoid_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5781.HypoidGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5781,
        )

        return self.__parent__._cast(_5781.HypoidGearSetMultibodyDynamicsAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5789.KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5789,
        )

        return self.__parent__._cast(
            _5789.KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5792.KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5792,
        )

        return self.__parent__._cast(
            _5792.KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5795.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5795,
        )

        return self.__parent__._cast(
            _5795.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis
        )

    @property
    def microphone_array_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5801.MicrophoneArrayMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5801,
        )

        return self.__parent__._cast(_5801.MicrophoneArrayMultibodyDynamicsAnalysis)

    @property
    def part_to_part_shear_coupling_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5809.PartToPartShearCouplingMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5809,
        )

        return self.__parent__._cast(
            _5809.PartToPartShearCouplingMultibodyDynamicsAnalysis
        )

    @property
    def planetary_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5811.PlanetaryGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5811,
        )

        return self.__parent__._cast(_5811.PlanetaryGearSetMultibodyDynamicsAnalysis)

    @property
    def rolling_ring_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5818.RollingRingAssemblyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5818,
        )

        return self.__parent__._cast(_5818.RollingRingAssemblyMultibodyDynamicsAnalysis)

    @property
    def root_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5821.RootAssemblyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5821,
        )

        return self.__parent__._cast(_5821.RootAssemblyMultibodyDynamicsAnalysis)

    @property
    def specialised_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5828.SpecialisedAssemblyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5828,
        )

        return self.__parent__._cast(_5828.SpecialisedAssemblyMultibodyDynamicsAnalysis)

    @property
    def spiral_bevel_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5831.SpiralBevelGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5831,
        )

        return self.__parent__._cast(_5831.SpiralBevelGearSetMultibodyDynamicsAnalysis)

    @property
    def spring_damper_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5835.SpringDamperMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5835,
        )

        return self.__parent__._cast(_5835.SpringDamperMultibodyDynamicsAnalysis)

    @property
    def straight_bevel_diff_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5838.StraightBevelDiffGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5838,
        )

        return self.__parent__._cast(
            _5838.StraightBevelDiffGearSetMultibodyDynamicsAnalysis
        )

    @property
    def straight_bevel_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5841.StraightBevelGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5841,
        )

        return self.__parent__._cast(
            _5841.StraightBevelGearSetMultibodyDynamicsAnalysis
        )

    @property
    def synchroniser_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5845.SynchroniserMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5845,
        )

        return self.__parent__._cast(_5845.SynchroniserMultibodyDynamicsAnalysis)

    @property
    def torque_converter_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5850.TorqueConverterMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5850,
        )

        return self.__parent__._cast(_5850.TorqueConverterMultibodyDynamicsAnalysis)

    @property
    def worm_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5859.WormGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5859,
        )

        return self.__parent__._cast(_5859.WormGearSetMultibodyDynamicsAnalysis)

    @property
    def zerol_bevel_gear_set_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5862.ZerolBevelGearSetMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5862,
        )

        return self.__parent__._cast(_5862.ZerolBevelGearSetMultibodyDynamicsAnalysis)

    @property
    def abstract_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "AbstractAssemblyMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AbstractAssemblyMultibodyDynamicsAnalysis(_5806.PartMultibodyDynamicsAnalysis):
    """AbstractAssemblyMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ABSTRACT_ASSEMBLY_MULTIBODY_DYNAMICS_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2704.AbstractAssembly":
        """mastapy.system_model.part_model.AbstractAssembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_design(self: "Self") -> "_2704.AbstractAssembly":
        """mastapy.system_model.part_model.AbstractAssembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_AbstractAssemblyMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_AbstractAssemblyMultibodyDynamicsAnalysis
        """
        return _Cast_AbstractAssemblyMultibodyDynamicsAnalysis(self)



"""JISB1603SplineJointDesign"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.detailed_rigid_connectors.splines import _1613

_JISB1603_SPLINE_JOINT_DESIGN = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.Splines", "JISB1603SplineJointDesign"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.detailed_rigid_connectors import _1600
    from mastapy._private.detailed_rigid_connectors.splines import _1628, _1633

    Self = TypeVar("Self", bound="JISB1603SplineJointDesign")
    CastSelf = TypeVar(
        "CastSelf", bound="JISB1603SplineJointDesign._Cast_JISB1603SplineJointDesign"
    )


__docformat__ = "restructuredtext en"
__all__ = ("JISB1603SplineJointDesign",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_JISB1603SplineJointDesign:
    """Special nested class for casting JISB1603SplineJointDesign to subclasses."""

    __parent__: "JISB1603SplineJointDesign"

    @property
    def iso4156_spline_joint_design(
        self: "CastSelf",
    ) -> "_1613.ISO4156SplineJointDesign":
        return self.__parent__._cast(_1613.ISO4156SplineJointDesign)

    @property
    def standard_spline_joint_design(
        self: "CastSelf",
    ) -> "_1633.StandardSplineJointDesign":
        from mastapy._private.detailed_rigid_connectors.splines import _1633

        return self.__parent__._cast(_1633.StandardSplineJointDesign)

    @property
    def spline_joint_design(self: "CastSelf") -> "_1628.SplineJointDesign":
        from mastapy._private.detailed_rigid_connectors.splines import _1628

        return self.__parent__._cast(_1628.SplineJointDesign)

    @property
    def detailed_rigid_connector_design(
        self: "CastSelf",
    ) -> "_1600.DetailedRigidConnectorDesign":
        from mastapy._private.detailed_rigid_connectors import _1600

        return self.__parent__._cast(_1600.DetailedRigidConnectorDesign)

    @property
    def jisb1603_spline_joint_design(self: "CastSelf") -> "JISB1603SplineJointDesign":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class JISB1603SplineJointDesign(_1613.ISO4156SplineJointDesign):
    """JISB1603SplineJointDesign

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _JISB1603_SPLINE_JOINT_DESIGN

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_JISB1603SplineJointDesign":
        """Cast to another type.

        Returns:
            _Cast_JISB1603SplineJointDesign
        """
        return _Cast_JISB1603SplineJointDesign(self)



"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import mixins
from mastapy._private.nodal_analysis.varying_input_components import _109

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_ConstraintType")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_ConstraintType",)


class EnumWithSelectedValue_ConstraintType(mixins.EnumWithSelectedValueMixin, Enum):
    """EnumWithSelectedValue_ConstraintType

    A specific implementation of 'EnumWithSelectedValue' for 'ConstraintType' types.
    """

    __qualname__ = "ConstraintType"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_ConstraintType]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_ConstraintType]",
    ) -> "_109.ConstraintType":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _109.ConstraintType
        """
        return _109.ConstraintType

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_ConstraintType]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _109.ConstraintType.type_()

    @property
    @exception_bridge
    def selected_value(self: "Self") -> "_109.ConstraintType":
        """mastapy.nodal_analysis.varying_input_components.ConstraintType

        Note:
            This property is readonly.
        """
        return None

    @property
    @exception_bridge
    def available_values(self: "Self") -> "List[_109.ConstraintType]":
        """List[mastapy.nodal_analysis.varying_input_components.ConstraintType]

        Note:
            This property is readonly.
        """
        return None



"""GearDesignAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.gears.analysis import _1361

_GEAR_DESIGN_ANALYSIS = python_net_import(
    "SMT.MastaAPI.Gears.Analysis", "GearDesignAnalysis"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.analysis import _1365, _1366, _1367
    from mastapy._private.gears.fe_model import _1343
    from mastapy._private.gears.fe_model.conical import _1350
    from mastapy._private.gears.fe_model.cylindrical import _1347
    from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import (
        _1236,
        _1237,
        _1238,
        _1240,
    )
    from mastapy._private.gears.gear_designs.face import _1119
    from mastapy._private.gears.gear_two_d_fe_analysis import _1023, _1024
    from mastapy._private.gears.load_case import _998
    from mastapy._private.gears.load_case.bevel import _1016
    from mastapy._private.gears.load_case.concept import _1013
    from mastapy._private.gears.load_case.conical import _1010
    from mastapy._private.gears.load_case.cylindrical import _1007
    from mastapy._private.gears.load_case.face import _1004
    from mastapy._private.gears.load_case.worm import _1001
    from mastapy._private.gears.ltca import _966
    from mastapy._private.gears.ltca.conical import _992
    from mastapy._private.gears.ltca.cylindrical import _981
    from mastapy._private.gears.manufacturing.bevel import (
        _901,
        _902,
        _903,
        _904,
        _914,
        _915,
        _920,
    )
    from mastapy._private.gears.manufacturing.cylindrical import _738, _742, _743

    Self = TypeVar("Self", bound="GearDesignAnalysis")
    CastSelf = TypeVar("CastSelf", bound="GearDesignAnalysis._Cast_GearDesignAnalysis")


__docformat__ = "restructuredtext en"
__all__ = ("GearDesignAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearDesignAnalysis:
    """Special nested class for casting GearDesignAnalysis to subclasses."""

    __parent__: "GearDesignAnalysis"

    @property
    def abstract_gear_analysis(self: "CastSelf") -> "_1361.AbstractGearAnalysis":
        return self.__parent__._cast(_1361.AbstractGearAnalysis)

    @property
    def cylindrical_gear_manufacturing_config(
        self: "CastSelf",
    ) -> "_738.CylindricalGearManufacturingConfig":
        from mastapy._private.gears.manufacturing.cylindrical import _738

        return self.__parent__._cast(_738.CylindricalGearManufacturingConfig)

    @property
    def cylindrical_manufactured_gear_duty_cycle(
        self: "CastSelf",
    ) -> "_742.CylindricalManufacturedGearDutyCycle":
        from mastapy._private.gears.manufacturing.cylindrical import _742

        return self.__parent__._cast(_742.CylindricalManufacturedGearDutyCycle)

    @property
    def cylindrical_manufactured_gear_load_case(
        self: "CastSelf",
    ) -> "_743.CylindricalManufacturedGearLoadCase":
        from mastapy._private.gears.manufacturing.cylindrical import _743

        return self.__parent__._cast(_743.CylindricalManufacturedGearLoadCase)

    @property
    def conical_gear_manufacturing_analysis(
        self: "CastSelf",
    ) -> "_901.ConicalGearManufacturingAnalysis":
        from mastapy._private.gears.manufacturing.bevel import _901

        return self.__parent__._cast(_901.ConicalGearManufacturingAnalysis)

    @property
    def conical_gear_manufacturing_config(
        self: "CastSelf",
    ) -> "_902.ConicalGearManufacturingConfig":
        from mastapy._private.gears.manufacturing.bevel import _902

        return self.__parent__._cast(_902.ConicalGearManufacturingConfig)

    @property
    def conical_gear_micro_geometry_config(
        self: "CastSelf",
    ) -> "_903.ConicalGearMicroGeometryConfig":
        from mastapy._private.gears.manufacturing.bevel import _903

        return self.__parent__._cast(_903.ConicalGearMicroGeometryConfig)

    @property
    def conical_gear_micro_geometry_config_base(
        self: "CastSelf",
    ) -> "_904.ConicalGearMicroGeometryConfigBase":
        from mastapy._private.gears.manufacturing.bevel import _904

        return self.__parent__._cast(_904.ConicalGearMicroGeometryConfigBase)

    @property
    def conical_pinion_manufacturing_config(
        self: "CastSelf",
    ) -> "_914.ConicalPinionManufacturingConfig":
        from mastapy._private.gears.manufacturing.bevel import _914

        return self.__parent__._cast(_914.ConicalPinionManufacturingConfig)

    @property
    def conical_pinion_micro_geometry_config(
        self: "CastSelf",
    ) -> "_915.ConicalPinionMicroGeometryConfig":
        from mastapy._private.gears.manufacturing.bevel import _915

        return self.__parent__._cast(_915.ConicalPinionMicroGeometryConfig)

    @property
    def conical_wheel_manufacturing_config(
        self: "CastSelf",
    ) -> "_920.ConicalWheelManufacturingConfig":
        from mastapy._private.gears.manufacturing.bevel import _920

        return self.__parent__._cast(_920.ConicalWheelManufacturingConfig)

    @property
    def gear_load_distribution_analysis(
        self: "CastSelf",
    ) -> "_966.GearLoadDistributionAnalysis":
        from mastapy._private.gears.ltca import _966

        return self.__parent__._cast(_966.GearLoadDistributionAnalysis)

    @property
    def cylindrical_gear_load_distribution_analysis(
        self: "CastSelf",
    ) -> "_981.CylindricalGearLoadDistributionAnalysis":
        from mastapy._private.gears.ltca.cylindrical import _981

        return self.__parent__._cast(_981.CylindricalGearLoadDistributionAnalysis)

    @property
    def conical_gear_load_distribution_analysis(
        self: "CastSelf",
    ) -> "_992.ConicalGearLoadDistributionAnalysis":
        from mastapy._private.gears.ltca.conical import _992

        return self.__parent__._cast(_992.ConicalGearLoadDistributionAnalysis)

    @property
    def gear_load_case_base(self: "CastSelf") -> "_998.GearLoadCaseBase":
        from mastapy._private.gears.load_case import _998

        return self.__parent__._cast(_998.GearLoadCaseBase)

    @property
    def worm_gear_load_case(self: "CastSelf") -> "_1001.WormGearLoadCase":
        from mastapy._private.gears.load_case.worm import _1001

        return self.__parent__._cast(_1001.WormGearLoadCase)

    @property
    def face_gear_load_case(self: "CastSelf") -> "_1004.FaceGearLoadCase":
        from mastapy._private.gears.load_case.face import _1004

        return self.__parent__._cast(_1004.FaceGearLoadCase)

    @property
    def cylindrical_gear_load_case(self: "CastSelf") -> "_1007.CylindricalGearLoadCase":
        from mastapy._private.gears.load_case.cylindrical import _1007

        return self.__parent__._cast(_1007.CylindricalGearLoadCase)

    @property
    def conical_gear_load_case(self: "CastSelf") -> "_1010.ConicalGearLoadCase":
        from mastapy._private.gears.load_case.conical import _1010

        return self.__parent__._cast(_1010.ConicalGearLoadCase)

    @property
    def concept_gear_load_case(self: "CastSelf") -> "_1013.ConceptGearLoadCase":
        from mastapy._private.gears.load_case.concept import _1013

        return self.__parent__._cast(_1013.ConceptGearLoadCase)

    @property
    def bevel_load_case(self: "CastSelf") -> "_1016.BevelLoadCase":
        from mastapy._private.gears.load_case.bevel import _1016

        return self.__parent__._cast(_1016.BevelLoadCase)

    @property
    def cylindrical_gear_tiff_analysis(
        self: "CastSelf",
    ) -> "_1023.CylindricalGearTIFFAnalysis":
        from mastapy._private.gears.gear_two_d_fe_analysis import _1023

        return self.__parent__._cast(_1023.CylindricalGearTIFFAnalysis)

    @property
    def cylindrical_gear_tiff_analysis_duty_cycle(
        self: "CastSelf",
    ) -> "_1024.CylindricalGearTIFFAnalysisDutyCycle":
        from mastapy._private.gears.gear_two_d_fe_analysis import _1024

        return self.__parent__._cast(_1024.CylindricalGearTIFFAnalysisDutyCycle)

    @property
    def face_gear_micro_geometry(self: "CastSelf") -> "_1119.FaceGearMicroGeometry":
        from mastapy._private.gears.gear_designs.face import _1119

        return self.__parent__._cast(_1119.FaceGearMicroGeometry)

    @property
    def cylindrical_gear_micro_geometry(
        self: "CastSelf",
    ) -> "_1236.CylindricalGearMicroGeometry":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1236

        return self.__parent__._cast(_1236.CylindricalGearMicroGeometry)

    @property
    def cylindrical_gear_micro_geometry_base(
        self: "CastSelf",
    ) -> "_1237.CylindricalGearMicroGeometryBase":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1237

        return self.__parent__._cast(_1237.CylindricalGearMicroGeometryBase)

    @property
    def cylindrical_gear_micro_geometry_duty_cycle(
        self: "CastSelf",
    ) -> "_1238.CylindricalGearMicroGeometryDutyCycle":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1238

        return self.__parent__._cast(_1238.CylindricalGearMicroGeometryDutyCycle)

    @property
    def cylindrical_gear_micro_geometry_per_tooth(
        self: "CastSelf",
    ) -> "_1240.CylindricalGearMicroGeometryPerTooth":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1240

        return self.__parent__._cast(_1240.CylindricalGearMicroGeometryPerTooth)

    @property
    def gear_fe_model(self: "CastSelf") -> "_1343.GearFEModel":
        from mastapy._private.gears.fe_model import _1343

        return self.__parent__._cast(_1343.GearFEModel)

    @property
    def cylindrical_gear_fe_model(self: "CastSelf") -> "_1347.CylindricalGearFEModel":
        from mastapy._private.gears.fe_model.cylindrical import _1347

        return self.__parent__._cast(_1347.CylindricalGearFEModel)

    @property
    def conical_gear_fe_model(self: "CastSelf") -> "_1350.ConicalGearFEModel":
        from mastapy._private.gears.fe_model.conical import _1350

        return self.__parent__._cast(_1350.ConicalGearFEModel)

    @property
    def gear_implementation_analysis(
        self: "CastSelf",
    ) -> "_1365.GearImplementationAnalysis":
        from mastapy._private.gears.analysis import _1365

        return self.__parent__._cast(_1365.GearImplementationAnalysis)

    @property
    def gear_implementation_analysis_duty_cycle(
        self: "CastSelf",
    ) -> "_1366.GearImplementationAnalysisDutyCycle":
        from mastapy._private.gears.analysis import _1366

        return self.__parent__._cast(_1366.GearImplementationAnalysisDutyCycle)

    @property
    def gear_implementation_detail(
        self: "CastSelf",
    ) -> "_1367.GearImplementationDetail":
        from mastapy._private.gears.analysis import _1367

        return self.__parent__._cast(_1367.GearImplementationDetail)

    @property
    def gear_design_analysis(self: "CastSelf") -> "GearDesignAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GearDesignAnalysis(_1361.AbstractGearAnalysis):
    """GearDesignAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_DESIGN_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_GearDesignAnalysis":
        """Cast to another type.

        Returns:
            _Cast_GearDesignAnalysis
        """
        return _Cast_GearDesignAnalysis(self)



"""GearSetLoadCaseBase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import utility
from mastapy._private.gears.analysis import _1372

_GEAR_SET_LOAD_CASE_BASE = python_net_import(
    "SMT.MastaAPI.Gears.LoadCase", "GearSetLoadCaseBase"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.analysis import _1363
    from mastapy._private.gears.load_case.bevel import _1018
    from mastapy._private.gears.load_case.concept import _1014
    from mastapy._private.gears.load_case.conical import _1011
    from mastapy._private.gears.load_case.cylindrical import _1008
    from mastapy._private.gears.load_case.face import _1005
    from mastapy._private.gears.load_case.worm import _1002

    Self = TypeVar("Self", bound="GearSetLoadCaseBase")
    CastSelf = TypeVar(
        "CastSelf", bound="GearSetLoadCaseBase._Cast_GearSetLoadCaseBase"
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearSetLoadCaseBase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearSetLoadCaseBase:
    """Special nested class for casting GearSetLoadCaseBase to subclasses."""

    __parent__: "GearSetLoadCaseBase"

    @property
    def gear_set_design_analysis(self: "CastSelf") -> "_1372.GearSetDesignAnalysis":
        return self.__parent__._cast(_1372.GearSetDesignAnalysis)

    @property
    def abstract_gear_set_analysis(self: "CastSelf") -> "_1363.AbstractGearSetAnalysis":
        from mastapy._private.gears.analysis import _1363

        return self.__parent__._cast(_1363.AbstractGearSetAnalysis)

    @property
    def worm_gear_set_load_case(self: "CastSelf") -> "_1002.WormGearSetLoadCase":
        from mastapy._private.gears.load_case.worm import _1002

        return self.__parent__._cast(_1002.WormGearSetLoadCase)

    @property
    def face_gear_set_load_case(self: "CastSelf") -> "_1005.FaceGearSetLoadCase":
        from mastapy._private.gears.load_case.face import _1005

        return self.__parent__._cast(_1005.FaceGearSetLoadCase)

    @property
    def cylindrical_gear_set_load_case(
        self: "CastSelf",
    ) -> "_1008.CylindricalGearSetLoadCase":
        from mastapy._private.gears.load_case.cylindrical import _1008

        return self.__parent__._cast(_1008.CylindricalGearSetLoadCase)

    @property
    def conical_gear_set_load_case(self: "CastSelf") -> "_1011.ConicalGearSetLoadCase":
        from mastapy._private.gears.load_case.conical import _1011

        return self.__parent__._cast(_1011.ConicalGearSetLoadCase)

    @property
    def concept_gear_set_load_case(self: "CastSelf") -> "_1014.ConceptGearSetLoadCase":
        from mastapy._private.gears.load_case.concept import _1014

        return self.__parent__._cast(_1014.ConceptGearSetLoadCase)

    @property
    def bevel_set_load_case(self: "CastSelf") -> "_1018.BevelSetLoadCase":
        from mastapy._private.gears.load_case.bevel import _1018

        return self.__parent__._cast(_1018.BevelSetLoadCase)

    @property
    def gear_set_load_case_base(self: "CastSelf") -> "GearSetLoadCaseBase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GearSetLoadCaseBase(_1372.GearSetDesignAnalysis):
    """GearSetLoadCaseBase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_SET_LOAD_CASE_BASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @name.setter
    @exception_bridge
    @enforce_parameter_types
    def name(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "Name", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def unit_duration(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "UnitDuration")

        if temp is None:
            return 0.0

        return temp

    @unit_duration.setter
    @exception_bridge
    @enforce_parameter_types
    def unit_duration(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "UnitDuration", float(value) if value is not None else 0.0
        )

    @property
    def cast_to(self: "Self") -> "_Cast_GearSetLoadCaseBase":
        """Cast to another type.

        Returns:
            _Cast_GearSetLoadCaseBase
        """
        return _Cast_GearSetLoadCaseBase(self)



"""ConicalSetFEModel"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.gears.fe_model import _1346
from mastapy._private.gears.manufacturing.bevel import _917

_CONICAL_SET_FE_MODEL = python_net_import(
    "SMT.MastaAPI.Gears.FEModel.Conical", "ConicalSetFEModel"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.analysis import _1363, _1372, _1377
    from mastapy._private.gears.fe_model.conical import _1353
    from mastapy._private.nodal_analysis import _61

    Self = TypeVar("Self", bound="ConicalSetFEModel")
    CastSelf = TypeVar("CastSelf", bound="ConicalSetFEModel._Cast_ConicalSetFEModel")


__docformat__ = "restructuredtext en"
__all__ = ("ConicalSetFEModel",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalSetFEModel:
    """Special nested class for casting ConicalSetFEModel to subclasses."""

    __parent__: "ConicalSetFEModel"

    @property
    def gear_set_fe_model(self: "CastSelf") -> "_1346.GearSetFEModel":
        return self.__parent__._cast(_1346.GearSetFEModel)

    @property
    def gear_set_implementation_detail(
        self: "CastSelf",
    ) -> "_1377.GearSetImplementationDetail":
        from mastapy._private.gears.analysis import _1377

        return self.__parent__._cast(_1377.GearSetImplementationDetail)

    @property
    def gear_set_design_analysis(self: "CastSelf") -> "_1372.GearSetDesignAnalysis":
        from mastapy._private.gears.analysis import _1372

        return self.__parent__._cast(_1372.GearSetDesignAnalysis)

    @property
    def abstract_gear_set_analysis(self: "CastSelf") -> "_1363.AbstractGearSetAnalysis":
        from mastapy._private.gears.analysis import _1363

        return self.__parent__._cast(_1363.AbstractGearSetAnalysis)

    @property
    def conical_set_fe_model(self: "CastSelf") -> "ConicalSetFEModel":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConicalSetFEModel(_1346.GearSetFEModel):
    """ConicalSetFEModel

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_SET_FE_MODEL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def element_order(self: "Self") -> "_61.ElementOrder":
        """mastapy.nodal_analysis.ElementOrder"""
        temp = pythonnet_property_get(self.wrapped, "ElementOrder")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.ElementOrder"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._61", "ElementOrder"
        )(value)

    @element_order.setter
    @exception_bridge
    @enforce_parameter_types
    def element_order(self: "Self", value: "_61.ElementOrder") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.ElementOrder"
        )
        pythonnet_property_set(self.wrapped, "ElementOrder", value)

    @property
    @exception_bridge
    def flank_data_source(self: "Self") -> "_1353.FlankDataSource":
        """mastapy.gears.fe_model.conical.FlankDataSource"""
        temp = pythonnet_property_get(self.wrapped, "FlankDataSource")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.FEModel.Conical.FlankDataSource"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.fe_model.conical._1353", "FlankDataSource"
        )(value)

    @flank_data_source.setter
    @exception_bridge
    @enforce_parameter_types
    def flank_data_source(self: "Self", value: "_1353.FlankDataSource") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.FEModel.Conical.FlankDataSource"
        )
        pythonnet_property_set(self.wrapped, "FlankDataSource", value)

    @property
    @exception_bridge
    def selected_design(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_ConicalSetManufacturingConfig":
        """ListWithSelectedItem[mastapy.gears.manufacturing.bevel.ConicalSetManufacturingConfig]"""
        temp = pythonnet_property_get(self.wrapped, "SelectedDesign")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_ConicalSetManufacturingConfig",
        )(temp)

    @selected_design.setter
    @exception_bridge
    @enforce_parameter_types
    def selected_design(
        self: "Self", value: "_917.ConicalSetManufacturingConfig"
    ) -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_ConicalSetManufacturingConfig.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "SelectedDesign", value)

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalSetFEModel":
        """Cast to another type.

        Returns:
            _Cast_ConicalSetFEModel
        """
        return _Cast_ConicalSetFEModel(self)



"""ThermalElectricMachineSetup"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.electric_machines import _1422

_THERMAL_ELECTRIC_MACHINE_SETUP = python_net_import(
    "SMT.MastaAPI.ElectricMachines.Thermal", "ThermalElectricMachineSetup"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.electric_machines import _1423
    from mastapy._private.electric_machines.thermal import _1488, _1498, _1506
    from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import _232
    from mastapy._private.utility import _1816

    Self = TypeVar("Self", bound="ThermalElectricMachineSetup")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ThermalElectricMachineSetup._Cast_ThermalElectricMachineSetup",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ThermalElectricMachineSetup",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ThermalElectricMachineSetup:
    """Special nested class for casting ThermalElectricMachineSetup to subclasses."""

    __parent__: "ThermalElectricMachineSetup"

    @property
    def electric_machine_setup_base(
        self: "CastSelf",
    ) -> "_1422.ElectricMachineSetupBase":
        return self.__parent__._cast(_1422.ElectricMachineSetupBase)

    @property
    def thermal_electric_machine_setup(
        self: "CastSelf",
    ) -> "ThermalElectricMachineSetup":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ThermalElectricMachineSetup(_1422.ElectricMachineSetupBase):
    """ThermalElectricMachineSetup

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _THERMAL_ELECTRIC_MACHINE_SETUP

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def number_of_additional_slices(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfAdditionalSlices")

        if temp is None:
            return 0

        return temp

    @number_of_additional_slices.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_additional_slices(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfAdditionalSlices",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_axial_slices(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfAxialSlices")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_elements(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfElements")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_nodes(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfNodes")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def meshing_options(self: "Self") -> "_1423.ElectricMachineThermalMeshingOptions":
        """mastapy.electric_machines.ElectricMachineThermalMeshingOptions

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeshingOptions")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def slice_length_information_reporter(
        self: "Self",
    ) -> "_1506.SliceLengthInformationReporter":
        """mastapy.electric_machines.thermal.SliceLengthInformationReporter

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SliceLengthInformationReporter")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def additional_slices(self: "Self") -> "List[_1488.AdditionalSliceSpecification]":
        """List[mastapy.electric_machines.thermal.AdditionalSliceSpecification]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AdditionalSlices")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def housing_channel_modification_factors(
        self: "Self",
    ) -> "List[_1498.HousingChannelModificationFactors]":
        """List[mastapy.electric_machines.thermal.HousingChannelModificationFactors]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "HousingChannelModificationFactors")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def user_defined_nodes(self: "Self") -> "List[_232.UserDefinedNodeInformation]":
        """List[mastapy.nodal_analysis.lumped_parameter_thermal_analysis.UserDefinedNodeInformation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "UserDefinedNodes")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @exception_bridge
    def add_user_defined_node(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "AddUserDefinedNode")

    @exception_bridge
    def generate_mesh(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "GenerateMesh")

    @exception_bridge
    @enforce_parameter_types
    def try_copy_user_defined_nodes_to_other_setups(
        self: "Self", setups: "List[ThermalElectricMachineSetup]"
    ) -> "_1816.MethodOutcome":
        """mastapy.utility.MethodOutcome

        Args:
            setups (List[mastapy.electric_machines.thermal.ThermalElectricMachineSetup])
        """
        setups = conversion.mp_to_pn_objects_in_dotnet_list(setups)
        method_result = pythonnet_method_call(
            self.wrapped, "TryCopyUserDefinedNodesToOtherSetups", setups
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @property
    def cast_to(self: "Self") -> "_Cast_ThermalElectricMachineSetup":
        """Cast to another type.

        Returns:
            _Cast_ThermalElectricMachineSetup
        """
        return _Cast_ThermalElectricMachineSetup(self)



"""PermissibleContinuousAxialLoadResults"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable

_PERMISSIBLE_CONTINUOUS_AXIAL_LOAD_RESULTS = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling",
    "PermissibleContinuousAxialLoadResults",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.bearing_results import _2183

    Self = TypeVar("Self", bound="PermissibleContinuousAxialLoadResults")
    CastSelf = TypeVar(
        "CastSelf",
        bound="PermissibleContinuousAxialLoadResults._Cast_PermissibleContinuousAxialLoadResults",
    )


__docformat__ = "restructuredtext en"
__all__ = ("PermissibleContinuousAxialLoadResults",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PermissibleContinuousAxialLoadResults:
    """Special nested class for casting PermissibleContinuousAxialLoadResults to subclasses."""

    __parent__: "PermissibleContinuousAxialLoadResults"

    @property
    def permissible_continuous_axial_load_results(
        self: "CastSelf",
    ) -> "PermissibleContinuousAxialLoadResults":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PermissibleContinuousAxialLoadResults(_0.APIBase):
    """PermissibleContinuousAxialLoadResults

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PERMISSIBLE_CONTINUOUS_AXIAL_LOAD_RESULTS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def allowable_axial_load_factor(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AllowableAxialLoadFactor")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def allowable_constant_axial_load_ntn(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AllowableConstantAxialLoadNTN")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def allowable_intermittent_axial_load_ntn(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AllowableIntermittentAxialLoadNTN")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def allowable_momentary_axial_load_ntn(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AllowableMomentaryAxialLoadNTN")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def axial_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AxialLoad")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def calculation_method(self: "Self") -> "_2183.CylindricalRollerMaxAxialLoadMethod":
        """mastapy.bearings.bearing_results.CylindricalRollerMaxAxialLoadMethod

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CalculationMethod")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Bearings.BearingResults.CylindricalRollerMaxAxialLoadMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings.bearing_results._2183",
            "CylindricalRollerMaxAxialLoadMethod",
        )(value)

    @property
    @exception_bridge
    def capacity_lubrication_factor_for_permissible_axial_load_grease(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "CapacityLubricationFactorForPermissibleAxialLoadGrease"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def capacity_lubrication_factor_for_permissible_axial_load_oil(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "CapacityLubricationFactorForPermissibleAxialLoadOil"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def diameter_exponent_factor_for_permissible_axial_load(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DiameterExponentFactorForPermissibleAxialLoad"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def diameter_scaling_factor_for_permissible_axial_load(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DiameterScalingFactorForPermissibleAxialLoad"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def maximum_permissible_axial_load_schaeffler(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MaximumPermissibleAxialLoadSchaeffler"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_axial_load_schaeffler(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PermissibleAxialLoadSchaeffler")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_axial_load_dimension_factor(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleAxialLoadDimensionFactor"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def permissible_axial_load_internal_dimension_factor(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleAxialLoadInternalDimensionFactor"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def permissible_axial_load_under_shaft_deflection_schaeffler(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleAxialLoadUnderShaftDeflectionSchaeffler"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_axial_load_for_brief_periods_skf(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleAxialLoadForBriefPeriodsSKF"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_axial_load_for_occasional_peak_loads_skf(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleAxialLoadForOccasionalPeakLoadsSKF"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_axial_loading_nachi(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PermissibleAxialLoadingNACHI")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_continuous_axial_load_skf(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PermissibleContinuousAxialLoadSKF")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def radial_load_lubrication_factor_for_permissible_axial_load_grease(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "RadialLoadLubricationFactorForPermissibleAxialLoadGrease"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def radial_load_lubrication_factor_for_permissible_axial_load_oil(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "RadialLoadLubricationFactorForPermissibleAxialLoadOil"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    @exception_bridge
    def safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SafetyFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_PermissibleContinuousAxialLoadResults":
        """Cast to another type.

        Returns:
            _Cast_PermissibleContinuousAxialLoadResults
        """
        return _Cast_PermissibleContinuousAxialLoadResults(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6021 import (
        AbstractAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6022 import (
        AbstractPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6023 import (
        AbstractShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6024 import (
        AbstractShaftOrHousingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6025 import (
        AbstractShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6026 import (
        AGMAGleasonConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6027 import (
        AGMAGleasonConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6028 import (
        AGMAGleasonConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6029 import (
        AssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6030 import (
        BearingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6031 import (
        BeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6032 import (
        BeltDriveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6033 import (
        BevelDifferentialGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6034 import (
        BevelDifferentialGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6035 import (
        BevelDifferentialGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6036 import (
        BevelDifferentialPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6037 import (
        BevelDifferentialSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6038 import (
        BevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6039 import (
        BevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6040 import (
        BevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6041 import (
        BoltedJointHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6042 import (
        BoltHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6043 import (
        ClutchConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6044 import (
        ClutchHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6045 import (
        ClutchHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6046 import (
        CoaxialConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6047 import (
        ComplianceAndForceData,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6048 import (
        ComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6049 import (
        ConceptCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6050 import (
        ConceptCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6051 import (
        ConceptCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6052 import (
        ConceptGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6053 import (
        ConceptGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6054 import (
        ConceptGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6055 import (
        ConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6056 import (
        ConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6057 import (
        ConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6058 import (
        ConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6059 import (
        ConnectorHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6060 import (
        CouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6061 import (
        CouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6062 import (
        CouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6063 import (
        CVTBeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6064 import (
        CVTHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6065 import (
        CVTPulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6066 import (
        CycloidalAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6067 import (
        CycloidalDiscCentralBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6068 import (
        CycloidalDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6069 import (
        CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6070 import (
        CylindricalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6071 import (
        CylindricalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6072 import (
        CylindricalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6073 import (
        CylindricalPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6074 import (
        DampingSpecification,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6075 import (
        DatumHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6076 import (
        DynamicModelForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6077 import (
        ElectricMachinePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6078 import (
        ElectricMachineRotorXForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6079 import (
        ElectricMachineRotorXMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6080 import (
        ElectricMachineRotorYForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6081 import (
        ElectricMachineRotorYMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6082 import (
        ElectricMachineRotorZForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6083 import (
        ElectricMachineStatorToothAxialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6084 import (
        ElectricMachineStatorToothLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6085 import (
        ElectricMachineStatorToothMomentsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6086 import (
        ElectricMachineStatorToothRadialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6087 import (
        ElectricMachineStatorToothTangentialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6088 import (
        ElectricMachineTorqueRipplePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6089 import (
        ExportOutputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6090 import (
        ExternalCADModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6091 import (
        FaceGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6092 import (
        FaceGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6093 import (
        FaceGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6094 import (
        FEPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6095 import (
        FlexiblePinAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6096 import (
        FrequencyOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6097 import (
        GearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6098 import (
        GearMeshExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6099 import (
        GearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6100 import (
        GearMeshMisalignmentExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6101 import (
        GearMeshTEExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6102 import (
        GearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6103 import (
        GeneralPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6104 import (
        GuideDxfModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6105 import (
        HarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6106 import (
        HarmonicAnalysisBarModelFEExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6107 import (
        HarmonicAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6108 import (
        HarmonicAnalysisExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6109 import (
        HarmonicAnalysisFEExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6110 import (
        HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6111 import (
        HarmonicAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6112 import (
        HarmonicAnalysisRootAssemblyAndFESharedExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6113 import (
        HarmonicAnalysisRootAssemblyExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6114 import (
        HarmonicAnalysisShaftExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6115 import (
        HarmonicAnalysisTorqueInputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6116 import (
        HarmonicAnalysisWithVaryingStiffnessStaticLoadCase,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6117 import (
        HypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6118 import (
        HypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6119 import (
        HypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6120 import (
        InterMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6121 import (
        KlingelnbergCycloPalloidConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6122 import (
        KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6123 import (
        KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6124 import (
        KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6125 import (
        KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6126 import (
        KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6127 import (
        KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6128 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6129 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6130 import (
        MassDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6131 import (
        MeasurementComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6132 import (
        MicrophoneArrayHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6133 import (
        MicrophoneHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6134 import (
        ModalCorrectionMethod,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6135 import (
        MountableComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6136 import (
        OilSealHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6137 import (
        PartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6138 import (
        PartToPartShearCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6139 import (
        PartToPartShearCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6140 import (
        PartToPartShearCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6141 import (
        PeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6142 import (
        PlanetaryConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6143 import (
        PlanetaryGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6144 import (
        PlanetCarrierHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6145 import (
        PointLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6146 import (
        PowerLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6147 import (
        PulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6148 import (
        ResponseCacheLevel,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6149 import (
        RingPinsHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6150 import (
        RingPinsToDiscConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6151 import (
        RollingRingAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6152 import (
        RollingRingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6153 import (
        RollingRingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6154 import (
        RootAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6155 import (
        ShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6156 import (
        ShaftHubConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6157 import (
        ShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6158 import (
        SingleNodePeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6159 import (
        SpecialisedAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6160 import (
        SpeedOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6161 import (
        SpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6162 import (
        SpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6163 import (
        SpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6164 import (
        SpringDamperConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6165 import (
        SpringDamperHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6166 import (
        SpringDamperHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6167 import (
        StiffnessOptionsForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6168 import (
        StraightBevelDiffGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6169 import (
        StraightBevelDiffGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6170 import (
        StraightBevelDiffGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6171 import (
        StraightBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6172 import (
        StraightBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6173 import (
        StraightBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6174 import (
        StraightBevelPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6175 import (
        StraightBevelSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6176 import (
        SynchroniserHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6177 import (
        SynchroniserHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6178 import (
        SynchroniserPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6179 import (
        SynchroniserSleeveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6180 import (
        TorqueConverterConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6181 import (
        TorqueConverterHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6182 import (
        TorqueConverterPumpHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6183 import (
        TorqueConverterTurbineHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6184 import (
        UnbalancedMassExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6185 import (
        UnbalancedMassHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6186 import (
        VirtualComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6187 import (
        WormGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6188 import (
        WormGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6189 import (
        WormGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6190 import (
        ZerolBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6191 import (
        ZerolBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6192 import (
        ZerolBevelGearSetHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses._6021": [
            "AbstractAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6022": [
            "AbstractPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6023": [
            "AbstractShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6024": [
            "AbstractShaftOrHousingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6025": [
            "AbstractShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6026": [
            "AGMAGleasonConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6027": [
            "AGMAGleasonConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6028": [
            "AGMAGleasonConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6029": [
            "AssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6030": [
            "BearingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6031": [
            "BeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6032": [
            "BeltDriveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6033": [
            "BevelDifferentialGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6034": [
            "BevelDifferentialGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6035": [
            "BevelDifferentialGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6036": [
            "BevelDifferentialPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6037": [
            "BevelDifferentialSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6038": [
            "BevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6039": [
            "BevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6040": [
            "BevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6041": [
            "BoltedJointHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6042": [
            "BoltHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6043": [
            "ClutchConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6044": [
            "ClutchHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6045": [
            "ClutchHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6046": [
            "CoaxialConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6047": [
            "ComplianceAndForceData"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6048": [
            "ComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6049": [
            "ConceptCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6050": [
            "ConceptCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6051": [
            "ConceptCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6052": [
            "ConceptGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6053": [
            "ConceptGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6054": [
            "ConceptGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6055": [
            "ConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6056": [
            "ConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6057": [
            "ConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6058": [
            "ConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6059": [
            "ConnectorHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6060": [
            "CouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6061": [
            "CouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6062": [
            "CouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6063": [
            "CVTBeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6064": [
            "CVTHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6065": [
            "CVTPulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6066": [
            "CycloidalAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6067": [
            "CycloidalDiscCentralBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6068": [
            "CycloidalDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6069": [
            "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6070": [
            "CylindricalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6071": [
            "CylindricalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6072": [
            "CylindricalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6073": [
            "CylindricalPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6074": [
            "DampingSpecification"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6075": [
            "DatumHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6076": [
            "DynamicModelForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6077": [
            "ElectricMachinePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6078": [
            "ElectricMachineRotorXForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6079": [
            "ElectricMachineRotorXMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6080": [
            "ElectricMachineRotorYForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6081": [
            "ElectricMachineRotorYMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6082": [
            "ElectricMachineRotorZForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6083": [
            "ElectricMachineStatorToothAxialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6084": [
            "ElectricMachineStatorToothLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6085": [
            "ElectricMachineStatorToothMomentsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6086": [
            "ElectricMachineStatorToothRadialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6087": [
            "ElectricMachineStatorToothTangentialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6088": [
            "ElectricMachineTorqueRipplePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6089": [
            "ExportOutputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6090": [
            "ExternalCADModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6091": [
            "FaceGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6092": [
            "FaceGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6093": [
            "FaceGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6094": [
            "FEPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6095": [
            "FlexiblePinAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6096": [
            "FrequencyOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6097": [
            "GearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6098": [
            "GearMeshExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6099": [
            "GearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6100": [
            "GearMeshMisalignmentExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6101": [
            "GearMeshTEExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6102": [
            "GearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6103": [
            "GeneralPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6104": [
            "GuideDxfModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6105": [
            "HarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6106": [
            "HarmonicAnalysisBarModelFEExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6107": [
            "HarmonicAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6108": [
            "HarmonicAnalysisExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6109": [
            "HarmonicAnalysisFEExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6110": [
            "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6111": [
            "HarmonicAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6112": [
            "HarmonicAnalysisRootAssemblyAndFESharedExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6113": [
            "HarmonicAnalysisRootAssemblyExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6114": [
            "HarmonicAnalysisShaftExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6115": [
            "HarmonicAnalysisTorqueInputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6116": [
            "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6117": [
            "HypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6118": [
            "HypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6119": [
            "HypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6120": [
            "InterMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6121": [
            "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6122": [
            "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6123": [
            "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6124": [
            "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6125": [
            "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6126": [
            "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6127": [
            "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6128": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6129": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6130": [
            "MassDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6131": [
            "MeasurementComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6132": [
            "MicrophoneArrayHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6133": [
            "MicrophoneHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6134": [
            "ModalCorrectionMethod"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6135": [
            "MountableComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6136": [
            "OilSealHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6137": [
            "PartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6138": [
            "PartToPartShearCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6139": [
            "PartToPartShearCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6140": [
            "PartToPartShearCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6141": [
            "PeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6142": [
            "PlanetaryConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6143": [
            "PlanetaryGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6144": [
            "PlanetCarrierHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6145": [
            "PointLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6146": [
            "PowerLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6147": [
            "PulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6148": [
            "ResponseCacheLevel"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6149": [
            "RingPinsHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6150": [
            "RingPinsToDiscConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6151": [
            "RollingRingAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6152": [
            "RollingRingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6153": [
            "RollingRingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6154": [
            "RootAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6155": [
            "ShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6156": [
            "ShaftHubConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6157": [
            "ShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6158": [
            "SingleNodePeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6159": [
            "SpecialisedAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6160": [
            "SpeedOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6161": [
            "SpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6162": [
            "SpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6163": [
            "SpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6164": [
            "SpringDamperConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6165": [
            "SpringDamperHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6166": [
            "SpringDamperHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6167": [
            "StiffnessOptionsForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6168": [
            "StraightBevelDiffGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6169": [
            "StraightBevelDiffGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6170": [
            "StraightBevelDiffGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6171": [
            "StraightBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6172": [
            "StraightBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6173": [
            "StraightBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6174": [
            "StraightBevelPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6175": [
            "StraightBevelSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6176": [
            "SynchroniserHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6177": [
            "SynchroniserHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6178": [
            "SynchroniserPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6179": [
            "SynchroniserSleeveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6180": [
            "TorqueConverterConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6181": [
            "TorqueConverterHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6182": [
            "TorqueConverterPumpHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6183": [
            "TorqueConverterTurbineHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6184": [
            "UnbalancedMassExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6185": [
            "UnbalancedMassHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6186": [
            "VirtualComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6187": [
            "WormGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6188": [
            "WormGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6189": [
            "WormGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6190": [
            "ZerolBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6191": [
            "ZerolBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6192": [
            "ZerolBevelGearSetHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyHarmonicAnalysis",
    "AbstractPeriodicExcitationDetail",
    "AbstractShaftHarmonicAnalysis",
    "AbstractShaftOrHousingHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionHarmonicAnalysis",
    "AGMAGleasonConicalGearHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshHarmonicAnalysis",
    "AGMAGleasonConicalGearSetHarmonicAnalysis",
    "AssemblyHarmonicAnalysis",
    "BearingHarmonicAnalysis",
    "BeltConnectionHarmonicAnalysis",
    "BeltDriveHarmonicAnalysis",
    "BevelDifferentialGearHarmonicAnalysis",
    "BevelDifferentialGearMeshHarmonicAnalysis",
    "BevelDifferentialGearSetHarmonicAnalysis",
    "BevelDifferentialPlanetGearHarmonicAnalysis",
    "BevelDifferentialSunGearHarmonicAnalysis",
    "BevelGearHarmonicAnalysis",
    "BevelGearMeshHarmonicAnalysis",
    "BevelGearSetHarmonicAnalysis",
    "BoltedJointHarmonicAnalysis",
    "BoltHarmonicAnalysis",
    "ClutchConnectionHarmonicAnalysis",
    "ClutchHalfHarmonicAnalysis",
    "ClutchHarmonicAnalysis",
    "CoaxialConnectionHarmonicAnalysis",
    "ComplianceAndForceData",
    "ComponentHarmonicAnalysis",
    "ConceptCouplingConnectionHarmonicAnalysis",
    "ConceptCouplingHalfHarmonicAnalysis",
    "ConceptCouplingHarmonicAnalysis",
    "ConceptGearHarmonicAnalysis",
    "ConceptGearMeshHarmonicAnalysis",
    "ConceptGearSetHarmonicAnalysis",
    "ConicalGearHarmonicAnalysis",
    "ConicalGearMeshHarmonicAnalysis",
    "ConicalGearSetHarmonicAnalysis",
    "ConnectionHarmonicAnalysis",
    "ConnectorHarmonicAnalysis",
    "CouplingConnectionHarmonicAnalysis",
    "CouplingHalfHarmonicAnalysis",
    "CouplingHarmonicAnalysis",
    "CVTBeltConnectionHarmonicAnalysis",
    "CVTHarmonicAnalysis",
    "CVTPulleyHarmonicAnalysis",
    "CycloidalAssemblyHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionHarmonicAnalysis",
    "CycloidalDiscHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis",
    "CylindricalGearHarmonicAnalysis",
    "CylindricalGearMeshHarmonicAnalysis",
    "CylindricalGearSetHarmonicAnalysis",
    "CylindricalPlanetGearHarmonicAnalysis",
    "DampingSpecification",
    "DatumHarmonicAnalysis",
    "DynamicModelForHarmonicAnalysis",
    "ElectricMachinePeriodicExcitationDetail",
    "ElectricMachineRotorXForcePeriodicExcitationDetail",
    "ElectricMachineRotorXMomentPeriodicExcitationDetail",
    "ElectricMachineRotorYForcePeriodicExcitationDetail",
    "ElectricMachineRotorYMomentPeriodicExcitationDetail",
    "ElectricMachineRotorZForcePeriodicExcitationDetail",
    "ElectricMachineStatorToothAxialLoadsExcitationDetail",
    "ElectricMachineStatorToothLoadsExcitationDetail",
    "ElectricMachineStatorToothMomentsExcitationDetail",
    "ElectricMachineStatorToothRadialLoadsExcitationDetail",
    "ElectricMachineStatorToothTangentialLoadsExcitationDetail",
    "ElectricMachineTorqueRipplePeriodicExcitationDetail",
    "ExportOutputType",
    "ExternalCADModelHarmonicAnalysis",
    "FaceGearHarmonicAnalysis",
    "FaceGearMeshHarmonicAnalysis",
    "FaceGearSetHarmonicAnalysis",
    "FEPartHarmonicAnalysis",
    "FlexiblePinAssemblyHarmonicAnalysis",
    "FrequencyOptionsForHarmonicAnalysisResults",
    "GearHarmonicAnalysis",
    "GearMeshExcitationDetail",
    "GearMeshHarmonicAnalysis",
    "GearMeshMisalignmentExcitationDetail",
    "GearMeshTEExcitationDetail",
    "GearSetHarmonicAnalysis",
    "GeneralPeriodicExcitationDetail",
    "GuideDxfModelHarmonicAnalysis",
    "HarmonicAnalysis",
    "HarmonicAnalysisBarModelFEExportOptions",
    "HarmonicAnalysisDrawStyle",
    "HarmonicAnalysisExportOptions",
    "HarmonicAnalysisFEExportOptions",
    "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation",
    "HarmonicAnalysisOptions",
    "HarmonicAnalysisRootAssemblyAndFESharedExportOptions",
    "HarmonicAnalysisRootAssemblyExportOptions",
    "HarmonicAnalysisShaftExportOptions",
    "HarmonicAnalysisTorqueInputType",
    "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase",
    "HypoidGearHarmonicAnalysis",
    "HypoidGearMeshHarmonicAnalysis",
    "HypoidGearSetHarmonicAnalysis",
    "InterMountableComponentConnectionHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis",
    "MassDiscHarmonicAnalysis",
    "MeasurementComponentHarmonicAnalysis",
    "MicrophoneArrayHarmonicAnalysis",
    "MicrophoneHarmonicAnalysis",
    "ModalCorrectionMethod",
    "MountableComponentHarmonicAnalysis",
    "OilSealHarmonicAnalysis",
    "PartHarmonicAnalysis",
    "PartToPartShearCouplingConnectionHarmonicAnalysis",
    "PartToPartShearCouplingHalfHarmonicAnalysis",
    "PartToPartShearCouplingHarmonicAnalysis",
    "PeriodicExcitationWithReferenceShaft",
    "PlanetaryConnectionHarmonicAnalysis",
    "PlanetaryGearSetHarmonicAnalysis",
    "PlanetCarrierHarmonicAnalysis",
    "PointLoadHarmonicAnalysis",
    "PowerLoadHarmonicAnalysis",
    "PulleyHarmonicAnalysis",
    "ResponseCacheLevel",
    "RingPinsHarmonicAnalysis",
    "RingPinsToDiscConnectionHarmonicAnalysis",
    "RollingRingAssemblyHarmonicAnalysis",
    "RollingRingConnectionHarmonicAnalysis",
    "RollingRingHarmonicAnalysis",
    "RootAssemblyHarmonicAnalysis",
    "ShaftHarmonicAnalysis",
    "ShaftHubConnectionHarmonicAnalysis",
    "ShaftToMountableComponentConnectionHarmonicAnalysis",
    "SingleNodePeriodicExcitationWithReferenceShaft",
    "SpecialisedAssemblyHarmonicAnalysis",
    "SpeedOptionsForHarmonicAnalysisResults",
    "SpiralBevelGearHarmonicAnalysis",
    "SpiralBevelGearMeshHarmonicAnalysis",
    "SpiralBevelGearSetHarmonicAnalysis",
    "SpringDamperConnectionHarmonicAnalysis",
    "SpringDamperHalfHarmonicAnalysis",
    "SpringDamperHarmonicAnalysis",
    "StiffnessOptionsForHarmonicAnalysis",
    "StraightBevelDiffGearHarmonicAnalysis",
    "StraightBevelDiffGearMeshHarmonicAnalysis",
    "StraightBevelDiffGearSetHarmonicAnalysis",
    "StraightBevelGearHarmonicAnalysis",
    "StraightBevelGearMeshHarmonicAnalysis",
    "StraightBevelGearSetHarmonicAnalysis",
    "StraightBevelPlanetGearHarmonicAnalysis",
    "StraightBevelSunGearHarmonicAnalysis",
    "SynchroniserHalfHarmonicAnalysis",
    "SynchroniserHarmonicAnalysis",
    "SynchroniserPartHarmonicAnalysis",
    "SynchroniserSleeveHarmonicAnalysis",
    "TorqueConverterConnectionHarmonicAnalysis",
    "TorqueConverterHarmonicAnalysis",
    "TorqueConverterPumpHarmonicAnalysis",
    "TorqueConverterTurbineHarmonicAnalysis",
    "UnbalancedMassExcitationDetail",
    "UnbalancedMassHarmonicAnalysis",
    "VirtualComponentHarmonicAnalysis",
    "WormGearHarmonicAnalysis",
    "WormGearMeshHarmonicAnalysis",
    "WormGearSetHarmonicAnalysis",
    "ZerolBevelGearHarmonicAnalysis",
    "ZerolBevelGearMeshHarmonicAnalysis",
    "ZerolBevelGearSetHarmonicAnalysis",
)
